@@ -90,14 +90,12 @@ if TYPE_CHECKING:
     from starlite.types.callable_types import AnyCallable, GetLogger
 
 DEFAULT_OPENAPI_CONFIG = OpenAPIConfig(title="Starlite API", version="1.0.0")
-"""
-    The default OpenAPI config used if not configuration is explicitly passed
-    to the [Starlite][starlite.app.Starlite] instance constructor.
+"""The default OpenAPI config used if not configuration is explicitly passed to the [Starlite][starlite.app.Starlite]
+instance constructor.
 """
 DEFAULT_CACHE_CONFIG = CacheConfig()
-"""
-    The default cache config used if not configuration is explicitly passed
-    to the [Starlite][starlite.app.Starlite] instance constructor.
+"""The default cache config used if not configuration is explicitly passed to the [Starlite][starlite.app.Starlite]
+instance constructor.
 """
 
 
@@ -112,7 +110,10 @@ class HandlerIndex(TypedDict):
     handler: "RouteHandlerType"
     """Route handler instance."""
     identifier: str
-    """Unique identifier of the handler. Either equal to the 'name' attribute or the __str__ value of the handler."""
+    """Unique identifier of the handler.
+
+    Either equal to the 'name' attribute or the __str__ value of the handler.
+    """
 
 
 class Starlite(Router):
@@ -344,7 +345,7 @@ class Starlite(Router):
         self.plugins = config.plugins
         self.request_class = config.request_class or Request
         self.static_files_config = config.static_files_config
-        self.template_engine = config.template_config.to_engine() if config.template_config else None
+        self.template_engine = config.template_config.engine_instance if config.template_config else None
         self.websocket_class = config.websocket_class or WebSocket
 
         super().__init__(
@@ -717,4 +718,6 @@ class Starlite(Router):
                     plugins=self.plugins,
                     use_handler_docstrings=self.openapi_config.use_handler_docstrings,
                 )
-        self.openapi_schema = construct_open_api_with_schema_class(self.openapi_schema)
+        self.openapi_schema = construct_open_api_with_schema_class(
+            open_api_schema=self.openapi_schema, by_alias=self.openapi_config.by_alias
+        )
