@@ -36,17 +36,11 @@ class Request(Generic[User, Auth], ASGIConnection["HTTPRouteHandler", User, Auth
     __slots__ = ("_json", "_form", "_body", "_msgpack", "_content_type", "is_connected")
 
     scope: "HTTPScope"
-    """
-    The ASGI scope attached to the connection.
-    """
+    """The ASGI scope attached to the connection."""
     receive: "Receive"
-    """
-    The ASGI receive function.
-    """
+    """The ASGI receive function."""
     send: "Send"
-    """
-    The ASGI send function.
-    """
+    """The ASGI send function."""
 
     def __init__(self, scope: "Scope", receive: "Receive" = empty_receive, send: "Send" = empty_send) -> None:
         """Initialize `Request`.
