@@ -48,17 +48,11 @@ class WebSocket(Generic[User, Auth], ASGIConnection["WebsocketRouteHandler", Use
     __slots__ = ("connection_state",)
 
     scope: "WebSocketScope"
-    """
-    The ASGI scope attached to the connection.
-    """
+    """The ASGI scope attached to the connection."""
     receive: "Receive"
-    """
-    The ASGI receive function.
-    """
+    """The ASGI receive function."""
     send: "Send"
-    """
-    The ASGI send function.
-    """
+    """The ASGI send function."""
 
     def __init__(self, scope: "Scope", receive: "Receive" = empty_receive, send: "Send" = empty_send) -> None:
         """Initialize `WebSocket`.
