@@ -45,9 +45,27 @@ def parse_query_string(query_string: bytes, encoding: str = "utf-8") -> Tuple[Tu
     )
 
 
+@lru_cache(1024)
+def parse_form_query_string(form_query_string: bytes, encoding: str = "utf-8") -> Tuple[Tuple[str, Any], ...]:
+    """Parse a form query string into a tuple of key value pairs.
+
+    Args:
+        form_query_string: A query string.
+        encoding: The encoding to use.
+
+    Returns:
+        A tuple of key value pairs.
+    """
+    _bools = {"true": True, "false": False, "True": True, "False": False}
+    return tuple(
+        (k, v if v not in _bools else _bools[v])
+        for k, v in parse_qsl(str(form_query_string, encoding=encoding), keep_blank_values=True)
+    )
+
+
 @lru_cache(1024)
 def parse_url_encoded_form_data(encoded_data: bytes, encoding: str) -> Dict[str, Any]:
-    """Parse a url encoded form data dict.
+    """Parse an url encoded form data dict.
 
     Args:
         encoded_data: The encoded byte string.
@@ -57,7 +75,7 @@ def parse_url_encoded_form_data(encoded_data: bytes, encoding: str) -> Dict[str,
         A parsed dict.
     """
     decoded_dict: DefaultDict[str, List[Any]] = defaultdict(list)
-    for k, v in parse_query_string(query_string=encoded_data, encoding=encoding):
+    for k, v in parse_form_query_string(form_query_string=encoded_data, encoding=encoding):
         with suppress(DecodeError):
             v = decode_json(v) if isinstance(v, str) else v
         decoded_dict[k].append(v)
